"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BullAdapter = void 0;
const base_1 = require("./base");
class BullAdapter extends base_1.BaseAdapter {
    constructor(queue, options = {}) {
        super({ ...options, allowCompletedRetries: false });
        this.queue = queue;
    }
    getRedisInfo() {
        return this.queue.client.info();
    }
    getName() {
        return `${this.prefix}${this.queue.name}`;
    }
    clean(jobStatus, graceTimeMs) {
        return this.queue.clean(graceTimeMs, jobStatus);
    }
    getJob(id) {
        return this.queue.getJob(id).then((job) => {
            if (typeof (job === null || job === void 0 ? void 0 : job.attemptsMade) === 'number') {
                job.attemptsMade++;
            }
            return job;
        });
    }
    getJobs(jobStatuses, start, end) {
        return this.queue.getJobs(jobStatuses, start, end).then((jobs) => jobs.map((job) => {
            if (typeof (job === null || job === void 0 ? void 0 : job.attemptsMade) === 'number') {
                job.attemptsMade++; // increase to align it with bullMQ behavior
            }
            return job;
        }));
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    getJobCounts(..._jobStatuses) {
        return this.queue.getJobCounts();
    }
    getJobLogs(id) {
        return this.queue.getJobLogs(id).then(({ logs }) => logs);
    }
    isPaused() {
        return this.queue.isPaused();
    }
    pause() {
        return this.queue.pause();
    }
    resume() {
        return this.queue.resume();
    }
    empty() {
        return this.queue.empty();
    }
}
exports.BullAdapter = BullAdapter;
//# sourceMappingURL=bull.js.map