"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const uuid_1 = require("uuid");
const stringz_1 = require("stringz");
const seedrandom = require("seedrandom");
const value_1 = require("../value");
const util_1 = require("../util");
const error_1 = require("../error");
const pkg = require('../../../package.json');
exports.std = {
    'help': value_1.STR('SEE: https://github.com/syuilo/aiscript/blob/master/docs/get-started.md'),
    //#region Core
    'Core:v': value_1.STR(pkg.version),
    'Core:ai': value_1.STR('kawaii'),
    'Core:not': value_1.FN_NATIVE(([a]) => {
        util_1.assertBoolean(a);
        return a.value ? value_1.FALSE : value_1.TRUE;
    }),
    'Core:eq': value_1.FN_NATIVE(([a, b]) => {
        return util_1.eq(a, b) ? value_1.TRUE : value_1.FALSE;
    }),
    'Core:neq': value_1.FN_NATIVE(([a, b]) => {
        return util_1.eq(a, b) ? value_1.FALSE : value_1.TRUE;
    }),
    'Core:and': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertBoolean(a);
        util_1.assertBoolean(b);
        return (a.value && b.value) ? value_1.TRUE : value_1.FALSE;
    }),
    'Core:or': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertBoolean(a);
        util_1.assertBoolean(b);
        return (a.value || b.value) ? value_1.TRUE : value_1.FALSE;
    }),
    'Core:add': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return value_1.NUM(a.value + b.value);
    }),
    'Core:sub': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return value_1.NUM(a.value - b.value);
    }),
    'Core:mul': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return value_1.NUM(a.value * b.value);
    }),
    'Core:div': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        const res = a.value / b.value;
        if (isNaN(res))
            throw new error_1.AiScriptError('Invalid operation.');
        return value_1.NUM(res);
    }),
    'Core:mod': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return value_1.NUM(a.value % b.value);
    }),
    'Core:gt': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return a.value > b.value ? value_1.TRUE : value_1.FALSE;
    }),
    'Core:lt': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return a.value < b.value ? value_1.TRUE : value_1.FALSE;
    }),
    'Core:gteq': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return a.value >= b.value ? value_1.TRUE : value_1.FALSE;
    }),
    'Core:lteq': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return a.value <= b.value ? value_1.TRUE : value_1.FALSE;
    }),
    'Core:type': value_1.FN_NATIVE(([v]) => {
        return value_1.STR(v.type);
    }),
    'Core:to_str': value_1.FN_NATIVE(([v]) => {
        if (v.type === 'str')
            return v;
        if (v.type === 'num')
            return value_1.STR(v.value.toString());
        return value_1.STR('?');
    }),
    //#endregion
    //#region Util
    'Util:uuid': value_1.FN_NATIVE(() => {
        return value_1.STR(uuid_1.v4());
    }),
    //#endregion
    //#region Json
    'Json:stringify': value_1.FN_NATIVE(([v]) => {
        return value_1.STR(JSON.stringify(util_1.valToJs(v)));
    }),
    'Json:parse': value_1.FN_NATIVE(([json]) => {
        util_1.assertString(json);
        return util_1.jsToVal(JSON.parse(json.value));
    }),
    //#endregion
    //#region Date
    'Date:now': value_1.FN_NATIVE(() => {
        return value_1.NUM(Date.now());
    }),
    'Date:year': value_1.FN_NATIVE(() => {
        return value_1.NUM(new Date().getFullYear());
    }),
    'Date:month': value_1.FN_NATIVE(() => {
        return value_1.NUM(new Date().getMonth() + 1);
    }),
    'Date:day': value_1.FN_NATIVE(() => {
        return value_1.NUM(new Date().getDate());
    }),
    'Date:hour': value_1.FN_NATIVE(() => {
        return value_1.NUM(new Date().getHours());
    }),
    'Date:minute': value_1.FN_NATIVE(() => {
        return value_1.NUM(new Date().getMinutes());
    }),
    'Date:second': value_1.FN_NATIVE(() => {
        return value_1.NUM(new Date().getSeconds());
    }),
    'Date:parse': value_1.FN_NATIVE(([v]) => {
        util_1.assertString(v);
        return value_1.NUM(new Date(v.value).getTime());
    }),
    //#endregion
    //#region Math
    'Math:PI': value_1.NUM(Math.PI),
    'Math:sin': value_1.FN_NATIVE(([v]) => {
        util_1.assertNumber(v);
        return value_1.NUM(Math.sin(v.value));
    }),
    'Math:cos': value_1.FN_NATIVE(([v]) => {
        util_1.assertNumber(v);
        return value_1.NUM(Math.cos(v.value));
    }),
    'Math:abs': value_1.FN_NATIVE(([v]) => {
        util_1.assertNumber(v);
        return value_1.NUM(Math.abs(v.value));
    }),
    'Math:sqrt': value_1.FN_NATIVE(([v]) => {
        util_1.assertNumber(v);
        const res = Math.sqrt(v.value);
        if (isNaN(res))
            throw new error_1.AiScriptError('Invalid operation.');
        return value_1.NUM(res);
    }),
    'Math:round': value_1.FN_NATIVE(([v]) => {
        util_1.assertNumber(v);
        return value_1.NUM(Math.round(v.value));
    }),
    'Math:floor': value_1.FN_NATIVE(([v]) => {
        util_1.assertNumber(v);
        return value_1.NUM(Math.floor(v.value));
    }),
    'Math:min': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return value_1.NUM(Math.min(a.value, b.value));
    }),
    'Math:max': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertNumber(a);
        util_1.assertNumber(b);
        return value_1.NUM(Math.max(a.value, b.value));
    }),
    'Math:rnd': value_1.FN_NATIVE(([min, max]) => {
        if (min && min.type === 'num' && max && max.type === 'num') {
            return value_1.NUM(Math.floor(Math.random() * (max.value - min.value + 1) + min.value));
        }
        return value_1.NUM(Math.random());
    }),
    'Math:gen_rng': value_1.FN_NATIVE(([seed]) => {
        if (seed.type !== 'num' && seed.type !== 'str')
            return value_1.NULL;
        const rng = seedrandom(seed.value.toString());
        return value_1.FN_NATIVE(([min, max]) => {
            if (min && min.type === 'num' && max && max.type === 'num') {
                return value_1.NUM(Math.floor(rng() * (max.value - min.value + 1) + min.value));
            }
            return value_1.NUM(rng());
        });
    }),
    //#endregion
    //#region Num
    'Num:to_hex': value_1.FN_NATIVE(([v]) => {
        util_1.assertNumber(v);
        return value_1.STR(v.value.toString(16));
    }),
    'Num:from_hex': value_1.FN_NATIVE(([v]) => {
        util_1.assertString(v);
        return value_1.NUM(parseInt(v.value, 16));
    }),
    //#endregion
    //#region Str
    'Str:lf': value_1.STR('\n'),
    'Str:to_num': value_1.FN_NATIVE(([v]) => {
        if (v.type === 'num')
            return v;
        if (v.type === 'str') {
            const parsed = parseInt(v.value, 10);
            if (isNaN(parsed))
                return value_1.NULL;
            return value_1.NUM(parsed);
        }
        return value_1.NULL;
    }),
    'Str:len': value_1.FN_NATIVE(([v]) => {
        if (v.type !== 'str')
            return value_1.NUM(0);
        return value_1.NUM(stringz_1.length(v.value));
    }),
    'Str:pick': value_1.FN_NATIVE(([v, i]) => {
        util_1.assertString(v);
        util_1.assertNumber(i);
        const chars = stringz_1.toArray(v.value);
        const char = chars[i.value - 1];
        return char ? value_1.STR(char) : value_1.NULL;
    }),
    'Str:incl': value_1.FN_NATIVE(([v, keyword]) => {
        util_1.assertString(v);
        util_1.assertString(keyword);
        return v.value.includes(keyword.value) ? value_1.TRUE : value_1.FALSE;
    }),
    'Str:slice': value_1.FN_NATIVE(([v, begin, end]) => {
        util_1.assertString(v);
        util_1.assertNumber(begin);
        util_1.assertNumber(end);
        return value_1.STR(stringz_1.substring(v.value, begin.value - 1, end.value - 1));
    }),
    'Str:split': value_1.FN_NATIVE(([v, splitter]) => {
        util_1.assertString(v);
        if (splitter)
            util_1.assertString(splitter);
        if (splitter) {
            return value_1.ARR(v.value.split(splitter ? splitter.value : '').map(s => value_1.STR(s)));
        }
        else {
            return value_1.ARR(stringz_1.toArray(v.value).map(s => value_1.STR(s)));
        }
    }),
    'Str:replace': value_1.FN_NATIVE(([v, a, b]) => {
        util_1.assertString(v);
        util_1.assertString(a);
        util_1.assertString(b);
        return value_1.STR(v.value.split(a.value).join(b.value));
    }),
    'Str:index_of': value_1.FN_NATIVE(([v, search]) => {
        util_1.assertString(v);
        util_1.assertString(search);
        return value_1.NUM(stringz_1.indexOf(v.value, search.value) + 1);
    }),
    'Str:trim': value_1.FN_NATIVE(([v]) => {
        util_1.assertString(v);
        return value_1.STR(v.value.trim());
    }),
    'Str:upper': value_1.FN_NATIVE(([v]) => {
        util_1.assertString(v);
        return value_1.STR(v.value.toUpperCase());
    }),
    'Str:lower': value_1.FN_NATIVE(([v]) => {
        util_1.assertString(v);
        return value_1.STR(v.value.toLowerCase());
    }),
    //#endregion
    //#region Arr
    'Arr:len': value_1.FN_NATIVE(([arr]) => {
        if (arr.type !== 'arr')
            return value_1.NUM(0);
        return value_1.NUM(arr.value.length);
    }),
    'Arr:push': value_1.FN_NATIVE(([arr, val]) => {
        util_1.assertArray(arr);
        arr.value.push(val);
        return value_1.NULL;
    }),
    'Arr:unshift': value_1.FN_NATIVE(([arr, val]) => {
        util_1.assertArray(arr);
        arr.value.unshift(val);
        return value_1.NULL;
    }),
    'Arr:pop': value_1.FN_NATIVE(([arr]) => {
        util_1.assertArray(arr);
        return arr.value.pop();
    }),
    'Arr:shift': value_1.FN_NATIVE(([arr]) => {
        util_1.assertArray(arr);
        return arr.value.shift();
    }),
    'Arr:concat': value_1.FN_NATIVE(([a, b]) => {
        util_1.assertArray(a);
        util_1.assertArray(b);
        return value_1.ARR(a.value.concat(b.value));
    }),
    'Arr:join': value_1.FN_NATIVE(([arr, joiner]) => {
        util_1.assertArray(arr);
        if (joiner)
            util_1.assertString(joiner);
        return value_1.STR(arr.value.map(i => i.type === 'str' ? i.value : '').join(joiner ? joiner.value : ''));
    }),
    'Arr:slice': value_1.FN_NATIVE(([arr, begin, end]) => {
        util_1.assertArray(arr);
        util_1.assertNumber(begin);
        util_1.assertNumber(end);
        return value_1.ARR(arr.value.slice(begin.value - 1, end.value - 1));
    }),
    'Arr:incl': value_1.FN_NATIVE(([arr, val]) => {
        util_1.assertArray(arr);
        if (val.type !== 'str' && val.type !== 'num' && val.type !== 'bool' && val.type !== 'null')
            return value_1.FALSE;
        const getValue = (v) => {
            return v.value.map(i => {
                if (i.type === 'str')
                    return i.value;
                if (i.type === 'num')
                    return i.value;
                if (i.type === 'bool')
                    return i.value;
                if (i.type === 'null')
                    return null;
                return Symbol();
            });
        };
        return getValue(arr).includes(val.type === 'null' ? null : val.value) ? value_1.TRUE : value_1.FALSE;
    }),
    'Arr:map': value_1.FN_NATIVE(async ([arr, fn], opts) => {
        util_1.assertArray(arr);
        util_1.assertFunction(fn);
        const vals = arr.value.map(async (item, i) => {
            return await opts.call(fn, [item, value_1.NUM(i + 1)]);
        });
        return value_1.ARR(await Promise.all(vals));
    }),
    'Arr:filter': value_1.FN_NATIVE(async ([arr, fn], opts) => {
        util_1.assertArray(arr);
        util_1.assertFunction(fn);
        const vals = [];
        for (let i = 0; i < arr.value.length; i++) {
            const item = arr.value[i];
            const res = await opts.call(fn, [item, value_1.NUM(i + 1)]);
            util_1.assertBoolean(res);
            if (res.value)
                vals.push(item);
        }
        return value_1.ARR(vals);
    }),
    'Arr:reduce': value_1.FN_NATIVE(async ([arr, fn, initialValue], opts) => {
        util_1.assertArray(arr);
        util_1.assertFunction(fn);
        const withInitialValue = initialValue != null;
        let accumulator = withInitialValue ? initialValue : arr.value[0];
        for (let i = withInitialValue ? 0 : 1; i < arr.value.length; i++) {
            const item = arr.value[i];
            accumulator = await opts.call(fn, [accumulator, item, value_1.NUM(i + 1)]);
        }
        return accumulator;
    }),
    'Arr:find': value_1.FN_NATIVE(async ([arr, fn], opts) => {
        util_1.assertArray(arr);
        util_1.assertFunction(fn);
        for (let i = 0; i < arr.value.length; i++) {
            const item = arr.value[i];
            const res = await opts.call(fn, [item, value_1.NUM(i + 1)]);
            util_1.assertBoolean(res);
            if (res.value)
                return item;
        }
        return value_1.NULL;
    }),
    'Arr:reverse': value_1.FN_NATIVE(([arr]) => {
        util_1.assertArray(arr);
        arr.value.reverse();
        return value_1.NULL;
    }),
    'Arr:copy': value_1.FN_NATIVE(async ([arr]) => {
        util_1.assertArray(arr);
        return value_1.ARR([...arr.value]);
    }),
    //#endregion
    //#region Obj
    'Obj:keys': value_1.FN_NATIVE(([obj]) => {
        util_1.assertObject(obj);
        return value_1.ARR(Array.from(obj.value.keys()).map(k => value_1.STR(k)));
    }),
    'Obj:kvs': value_1.FN_NATIVE(([obj]) => {
        util_1.assertObject(obj);
        return value_1.ARR(Array.from(obj.value.entries()).map(([k, v]) => value_1.ARR([value_1.STR(k), v])));
    }),
    'Obj:get': value_1.FN_NATIVE(([obj, key]) => {
        util_1.assertObject(obj);
        util_1.assertString(key);
        return obj.value.get(key.value) || value_1.NULL;
    }),
    'Obj:set': value_1.FN_NATIVE(([obj, key, value]) => {
        util_1.assertObject(obj);
        util_1.assertString(key);
        obj.value.set(key.value, value);
        return value_1.NULL;
    }),
    'Obj:has': value_1.FN_NATIVE(([obj, key]) => {
        util_1.assertObject(obj);
        util_1.assertString(key);
        return value_1.BOOL(obj.value.has(key.value));
    }),
    'Obj:copy': value_1.FN_NATIVE(([obj]) => {
        util_1.assertObject(obj);
        return value_1.OBJ(new Map(obj.value));
    }),
    /* TODO
    'Obj:merge': FN_NATIVE(([a, b]) => {
        assertObject(a);
        assertObject(b);
        return OBJ();
    }),
    */
    //#endregion
    //#region Async
    'Async:interval': value_1.FN_NATIVE(async ([interval, callback, immediate], opts) => {
        util_1.assertNumber(interval);
        util_1.assertFunction(callback);
        if (immediate)
            util_1.assertBoolean(immediate);
        if (immediate)
            opts.call(callback, []);
        const id = setInterval(() => {
            opts.call(callback, []);
        }, interval.value);
        const abortHandler = () => {
            clearInterval(id);
        };
        opts.registerAbortHandler(abortHandler);
        // stopper
        return value_1.FN_NATIVE(([], opts) => {
            clearInterval(id);
            opts.unregisterAbortHandler(abortHandler);
        });
    }),
    'Async:timeout': value_1.FN_NATIVE(async ([delay, callback], opts) => {
        util_1.assertNumber(delay);
        util_1.assertFunction(callback);
        const id = setTimeout(() => {
            opts.call(callback, []);
        }, delay.value);
        const abortHandler = () => {
            clearTimeout(id);
        };
        opts.registerAbortHandler(abortHandler);
        // stopper
        return value_1.FN_NATIVE(([], opts) => {
            clearTimeout(id);
            opts.unregisterAbortHandler(abortHandler);
        });
    }),
};
//# sourceMappingURL=std.js.map