"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const autobind_decorator_1 = require("autobind-decorator");
const error_1 = require("./error");
class Scope {
    constructor(layerdStates = [], parent, name) {
        this.opts = {};
        this.layerdStates = layerdStates;
        this.parent = parent;
        this.name = name || (layerdStates.length === 1 ? '<root>' : '<anonymous>');
    }
    log(type, params) {
        if (this.parent) {
            this.parent.log(type, params);
        }
        else {
            if (this.opts.log)
                this.opts.log(type, params);
        }
    }
    onUpdated(name, value) {
        if (this.parent) {
            this.parent.onUpdated(name, value);
        }
        else {
            if (this.opts.onUpdated)
                this.opts.onUpdated(name, value);
        }
    }
    createChildScope(states = new Map(), name) {
        const layer = [states, ...this.layerdStates];
        return new Scope(layer, this, name);
    }
    /**
     * 指定した名前の変数を取得します
     * @param name 変数名
     */
    get(name) {
        for (const layer of this.layerdStates) {
            if (layer.has(name)) {
                const state = layer.get(name);
                this.log('read', { var: name, val: state });
                return state;
            }
        }
        throw new error_1.AiScriptError(`No such variable '${name}' in scope '${this.name}'`, {
            scope: this.layerdStates
        });
    }
    /**
     * 指定した名前の変数を現在のスコープに追加します
     * @param name 変数名
     * @param val 初期値
     */
    add(name, val) {
        this.log('add', { var: name, val: val });
        if (this.layerdStates[0].has(name)) {
            throw new error_1.AiScriptError(`Variable '${name}' is alerady exists in scope '${this.name}'`, {
                scope: this.layerdStates
            });
        }
        this.layerdStates[0].set(name, val);
        if (this.parent == null)
            this.onUpdated(name, val);
    }
    /**
     * 指定した名前の変数に値を再代入します
     * @param name 変数名
     * @param val 値
     */
    assign(name, val) {
        let i = 1;
        for (const layer of this.layerdStates) {
            if (layer.has(name)) {
                layer.set(name, val);
                this.log('assign', { var: name, val: val });
                if (i === this.layerdStates.length)
                    this.onUpdated(name, val);
                return;
            }
            i++;
        }
        throw new error_1.AiScriptError(`No such variable '${name}' in scope '${this.name}'`, {
            scope: this.layerdStates
        });
    }
}
__decorate([
    autobind_decorator_1.default
], Scope.prototype, "log", null);
__decorate([
    autobind_decorator_1.default
], Scope.prototype, "onUpdated", null);
__decorate([
    autobind_decorator_1.default
], Scope.prototype, "createChildScope", null);
__decorate([
    autobind_decorator_1.default
], Scope.prototype, "get", null);
__decorate([
    autobind_decorator_1.default
], Scope.prototype, "add", null);
__decorate([
    autobind_decorator_1.default
], Scope.prototype, "assign", null);
exports.Scope = Scope;
//# sourceMappingURL=scope.js.map