"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const value_1 = require("./value");
const error_1 = require("./error");
function assertBoolean(val) {
    if (val.type !== 'bool') {
        throw new error_1.AiScriptError(`Expect boolean, but got ${val.type}.`);
    }
}
exports.assertBoolean = assertBoolean;
function assertFunction(val) {
    if (val.type !== 'fn') {
        throw new error_1.AiScriptError(`Expect function, but got ${val.type}.`);
    }
}
exports.assertFunction = assertFunction;
function assertString(val) {
    if (val.type !== 'str') {
        throw new error_1.AiScriptError(`Expect string, but got ${val.type}.`);
    }
}
exports.assertString = assertString;
function assertNumber(val) {
    if (val.type !== 'num') {
        throw new error_1.AiScriptError(`Expect number, but got ${val.type}.`);
    }
}
exports.assertNumber = assertNumber;
function assertObject(val) {
    if (val.type !== 'obj') {
        throw new error_1.AiScriptError(`Expect object, but got ${val.type}.`);
    }
}
exports.assertObject = assertObject;
function assertArray(val) {
    if (val.type !== 'arr') {
        throw new error_1.AiScriptError(`Expect array, but got ${val.type}.`);
    }
}
exports.assertArray = assertArray;
function eq(a, b) {
    if (a.type === 'fn' || b.type === 'fn')
        return false;
    if (a.type === 'null' && b.type === 'null')
        return true;
    if (a.type === 'null' || b.type === 'null')
        return false;
    return (a.value === b.value);
}
exports.eq = eq;
function valToString(val, simple = false) {
    if (simple) {
        if (val.type === 'num')
            return val.value;
        if (val.type === 'bool')
            return val.value ? 'yes' : 'no';
        if (val.type === 'str')
            return `"${val.value}"`;
        if (val.type === 'arr')
            return `[${val.value.map(item => valToString(item, true)).join(', ')}]`;
        if (val.type === 'null')
            return '(null)';
    }
    const label = val.type === 'num' ? val.value :
        val.type === 'bool' ? val.value :
            val.type === 'str' ? `"${val.value}"` :
                val.type === 'fn' ? '...' :
                    val.type === 'obj' ? '...' :
                        val.type === 'null' ? '' :
                            null;
    return `${val.type}<${label}>`;
}
exports.valToString = valToString;
function nodeToString(node) {
    const label = node.type === 'num' ? node.value :
        node.type === 'bool' ? node.value :
            node.type === 'str' ? node.value :
                node.type === 'fn' ? null :
                    node.type === 'null' ? null :
                        node.type === 'def' ? node.name :
                            node.type === 'var' ? node.name :
                                node.type === 'call' ? node.name :
                                    null;
    return label ? `${node.type.toUpperCase()} (${label})` : node.type.toUpperCase();
}
exports.nodeToString = nodeToString;
function valToJs(val) {
    switch (val.type) {
        case 'arr': return val.value.map(item => valToJs(item));
        case 'bool': return val.value;
        case 'null': return null;
        case 'num': return val.value;
        case 'obj': {
            const obj = {};
            for (const [k, v] of val.value.entries()) {
                // TODO: keyが__proto__とかじゃないかチェック
                obj[k] = valToJs(v);
            }
            return obj;
        }
        case 'str': return val.value;
        default: return undefined;
    }
}
exports.valToJs = valToJs;
function jsToVal(val) {
    if (val === null)
        return value_1.NULL;
    if (typeof val === 'boolean')
        return value_1.BOOL(val);
    if (typeof val === 'string')
        return value_1.STR(val);
    if (typeof val === 'number')
        return value_1.NUM(val);
    if (Array.isArray(val))
        return value_1.ARR(val.map(item => jsToVal(item)));
    if (typeof val === 'object') {
        const obj = new Map();
        for (const [k, v] of Object.entries(val)) {
            obj.set(k, jsToVal(v));
        }
        return value_1.OBJ(obj);
    }
    return value_1.NULL;
}
exports.jsToVal = jsToVal;
//# sourceMappingURL=util.js.map