"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const types = {
    def: 0,
    assign: 1,
    call: 2,
    return: 3,
    if: 4,
    for: 5,
    forOf: 6,
    var: 7,
    null: 8,
    bool: 9,
    num: 10,
    str: 11,
    arr: 12,
    fn: 13,
    obj: 14,
    prop: 15,
    propCall: 16,
    index: 17,
    block: 18,
    tmpl: 19,
    ns: 20,
    match: 21,
    meta: 22,
    propAssign: 23,
    indexAssign: 24,
    inc: 25,
    dec: 26,
};
function serializeOne(node) {
    if (node == null)
        return null;
    switch (node.type) {
        case 'def': return [types[node.type], node.name, node.mut, serializeOne(node.expr)];
        case 'assign': return [types[node.type], node.name, serializeOne(node.expr)];
        case 'call': return [types[node.type], node.name, serialize(node.args)];
        case 'return': return [types[node.type], serializeOne(node.expr)];
        case 'if': return [types[node.type], serializeOne(node.cond), serializeOne(node.then), node.elseif.map(x => [serializeOne(x.cond), serializeOne(x.then)]), serializeOne(node.else)];
        case 'for': return [types[node.type], node.var, serializeOne(node.from), serializeOne(node.to), serializeOne(node.times), serializeOne(node.for)];
        case 'forOf': return [types[node.type], node.var, serializeOne(node.items), serializeOne(node.for)];
        case 'var': return [types[node.type], node.name];
        case 'null': return [types[node.type]];
        case 'bool': return [types[node.type], node.value];
        case 'num': return [types[node.type], node.value];
        case 'str': return [types[node.type], node.value];
        case 'arr': return [types[node.type], serialize(node.value)];
        case 'fn': return [types[node.type], node.args, serialize(node.children)];
        case 'obj': return [types[node.type], Array.from(node.value.entries()).map(x => [x[0], serializeOne(x[1])])];
        case 'prop': return [types[node.type], node.obj, node.path];
        case 'propCall': return [types[node.type], node.obj, node.path, serialize(node.args)];
        case 'index': return [types[node.type], node.arr, serializeOne(node.i)];
        case 'block': return [types[node.type], serialize(node.statements)];
        case 'tmpl': return [types[node.type], node.tmpl.map(x => typeof x === 'string' ? x : serializeOne(x))];
        case 'ns': return [types[node.type], node.name, serialize(node.members)];
        case 'match': return [types[node.type], serializeOne(node.about), node.qs.map(x => [serializeOne(x.q), serializeOne(x.a)]), serializeOne(node.default)];
        case 'meta': return [types[node.type], node.name, serializeOne(node.value)];
        case 'propAssign': return [types[node.type], node.obj, node.path, serializeOne(node.expr)];
        case 'indexAssign': return [types[node.type], node.arr, serializeOne(node.i), serializeOne(node.expr)];
        case 'inc': return [types[node.type], node.name, serializeOne(node.expr)];
        case 'dec': return [types[node.type], node.name, serializeOne(node.expr)];
    }
}
exports.serializeOne = serializeOne;
function serialize(ast) {
    return ast.map(x => serializeOne(x));
}
exports.serialize = serialize;
function deserializeOne(bin) {
    if (bin == null)
        return undefined;
    const type = Object.keys(types).find(x => types[x] === bin[0]);
    switch (bin[0]) {
        case types.def: return { type, name: bin[1], mut: bin[2], expr: deserializeOne(bin[3]), };
        case types.assign: return { type, name: bin[1], expr: deserializeOne(bin[2]), };
        case types.call: return { type, name: bin[1], args: deserialize(bin[2]), };
        case types.return: return { type, expr: deserializeOne(bin[1]), };
        case types.if: return { type, cond: deserializeOne(bin[1]), then: deserializeOne(bin[2]), elseif: bin[3].map(x => ({ cond: deserializeOne(x[0]), then: deserializeOne(x[1]) })), else: deserializeOne(bin[4]), };
        case types.for: return { type, var: bin[1] || undefined, from: deserializeOne(bin[2]), to: deserializeOne(bin[3]), times: deserializeOne(bin[4]), for: deserializeOne(bin[5]), };
        case types.forOf: return { type, var: bin[1], items: deserializeOne(bin[2]), for: deserializeOne(bin[3]), };
        case types.var: return { type, name: bin[1], };
        case types.null: return { type, };
        case types.bool: return { type, value: bin[1], };
        case types.num: return { type, value: bin[1], };
        case types.str: return { type, value: bin[1], };
        case types.arr: return { type, value: deserialize(bin[1]), };
        case types.fn: return { type, args: bin[1], children: deserialize(bin[2]), };
        case types.obj: return { type, value: new Map(bin[1].map(x => [x[0], deserializeOne(x[1])])), };
        case types.prop: return { type, obj: bin[1], path: bin[2], };
        case types.propCall: return { type, obj: bin[1], path: bin[2], args: deserialize(bin[3]), };
        case types.index: return { type, arr: bin[1], i: deserializeOne(bin[2]), };
        case types.block: return { type, statements: deserialize(bin[1]), };
        case types.tmpl: return { type, tmpl: bin[1].map(x => typeof x === 'string' ? x : deserializeOne(x)), };
        case types.ns: return { type, name: bin[1], members: deserialize(bin[2]), };
        case types.match: return { type, about: deserializeOne(bin[1]), qs: bin[2].map(x => ({ q: deserializeOne(x[0]), a: deserializeOne(x[1]) })), default: deserializeOne(bin[3]), };
        case types.meta: return { type, name: bin[1], value: deserializeOne(bin[2]), };
        case types.propAssign: return { type, obj: bin[1], path: bin[2], expr: deserializeOne(bin[3]), };
        case types.indexAssign: return { type, arr: bin[1], i: deserializeOne(bin[2]), expr: deserializeOne(bin[3]), };
        case types.inc: return { type, name: bin[1], expr: deserializeOne(bin[2]), };
        case types.dec: return { type, name: bin[1], expr: deserializeOne(bin[2]), };
    }
    throw new Error("deserialization failed");
}
exports.deserializeOne = deserializeOne;
function deserialize(bin) {
    return bin.map(x => deserializeOne(x));
}
exports.deserialize = deserialize;
//# sourceMappingURL=serializer.js.map